@@ -10,12 +10,11 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 import functools
 import ipaddress
 
-import munch
+from cliff import columns
 from openstackclient.identity import common as identity_common
 from osc_lib import exceptions as osc_exc
 from osc_lib import utils
@@ -253,6 +252,7 @@ def get_loadbalancer_attrs(client_manager, parsed_args):
             'policies',
             client_manager.neutronclient.list_qos_policies,
         ),
+        'vip_vnic_type': ('vip_vnic_type', str),
         'enable': ('admin_state_up', lambda x: True),
         'disable': ('admin_state_up', lambda x: False),
         'cascade': ('cascade', lambda x: True),
@@ -324,6 +324,9 @@ def get_listener_attrs(client_manager, parsed_args):
         'tls_ciphers': ('tls_ciphers', str),
         'tls_versions': ('tls_versions', list),
         'alpn_protocols': ('alpn_protocols', list),
+        'hsts_max_age': ('hsts_max_age', int),
+        'hsts_include_subdomains': ('hsts_include_subdomains', bool),
+        'hsts_preload': ('hsts_preload', bool),
     }
     add_tags_attr_map(attr_map)
 
@@ -416,6 +419,8 @@ def get_member_attrs(client_manager, parsed_args):
         'monitor_address': ('monitor_address', str),
         'enable': ('admin_state_up', lambda x: True),
         'disable': ('admin_state_up', lambda x: False),
+        'request_sriov': ('request_sriov', lambda x: True),
+        'vnic_type': ('vnic_type', str),
     }
     add_tags_attr_map(attr_map)
 
@@ -576,6 +581,7 @@ def get_amphora_attrs(client_manager, parsed_args):
         'compute_id': ('compute_id', str),
         'role': ('role', str),
         'status': ('status', str),
+        'image_id': ('image_id', str),
     }
 
     return _map_attrs(vars(parsed_args), attr_map)
@@ -677,11 +683,25 @@ def get_availabilityzoneprofile_attrs(client_manager, parsed_args):
 
 
 def format_list(data):
-    return '\n'.join(i['id'] for i in data)
+    if data:
+        return '\n'.join(i['id'] for i in data)
+    return None
+
+
+class ListColumn(columns.FormattableColumn):
+    def human_readable(self):
+        return format_list(self._value)
 
 
 def format_list_flat(data):
-    return '\n'.join(i for i in data)
+    if data:
+        return '\n'.join(i for i in data)
+    return None
+
+
+class FlatListColumn(columns.FormattableColumn):
+    def human_readable(self):
+        return format_list_flat(self._value)
 
 
 def format_hash(data):
@@ -690,6 +710,11 @@ def format_hash(data):
     return None
 
 
+class HashColumn(columns.FormattableColumn):
+    def human_readable(self):
+        return format_hash(self._value)
+
+
 def _format_kv(data):
     formatted_kv = {}
     values = data.split(',')
@@ -716,9 +741,13 @@ def get_unsets(parsed_args):
     return unsets
 
 
+class _Munch(dict):
+    __getattr__ = dict.get
+
+
 def wait_for_active(status_f, res_id):
     success = utils.wait_for_status(
-        status_f=lambda x: munch.Munch(status_f(x)),
+        status_f=lambda x: _Munch(status_f(x)),
         res_id=res_id,
         status_field=constants.PROVISIONING_STATUS,
         sleep_time=3
@@ -734,7 +763,7 @@ def wait_for_delete(status_f, res_id,
     class Getter(object):
         @staticmethod
         def get(id):
-            return munch.Munch(status_f(id))
+            return _Munch(status_f(id))
 
     try:
         success = utils.wait_for_delete(
